@@ -9,6 +9,8 @@
 import os  # noqa: F401
 import re  # noqa: F401
 import sys  # noqa: F401
+from types import MethodType
+from types import FunctionType
 
 from apivideo.api_client import ApiClient
 from apivideo.endpoint import EndPoint as _EndPoint
@@ -322,7 +324,7 @@ class RawStatisticsApi(_EndPoint):
         ):
             """List video player sessions  # noqa: E501
 
-            Retrieve all available user sessions for a specific video.  # noqa: E501
+            Retrieve all available user sessions for a specific video. Tutorials that use the [analytics endpoint](https://api.video/blog/endpoints/analytics).  # noqa: E501
             This method makes a synchronous HTTP request by default. To make an
             asynchronous HTTP request, please pass async_req=True
 
@@ -334,7 +336,7 @@ class RawStatisticsApi(_EndPoint):
 
             Keyword Args:
                 period (str): Period must have one of the following formats:  - For a day : 2018-01-01, - For a week: 2018-W01, - For a month: 2018-01 - For a year: 2018  For a range period: -  Date range: 2018-01-01/2018-01-15 . [optional]
-                metadata ([str]): Metadata and Dynamic Metadata filter. Send an array of key value pairs you want to filter sessios with.. [optional]
+                metadata ({str: (str,)}): Metadata and Dynamic Metadata filter. Send an array of key value pairs you want to filter sessios with.. [optional]
                 current_page (int): Choose the number of search results to return per page. Minimum value: 1. [optional] if omitted the server will use the default value of 1
                 page_size (int): Results per page. Allowed values 1-100, default is 25.. [optional] if omitted the server will use the default value of 25
                 _return_http_data_only (bool): response data without head status
@@ -401,7 +403,7 @@ class RawStatisticsApi(_EndPoint):
                 'period':
                     (str,),
                 'metadata':
-                    ([str],),
+                    ({str: (str,)},),
                 'current_page':
                     (int,),
                 'page_size':
@@ -426,7 +428,7 @@ class RawStatisticsApi(_EndPoint):
                 'page_size': 'query',
             }
             collection_format_map = {
-                'metadata': 'multi',
+                'metadata': 'deepObject',
             }
 
             for key, value in kwargs.items():
